@@ -1,7 +1,6 @@
 <?php
 
 use Symfony\Component\Console\Output\BufferedOutput;
-use Termwind\HtmlRenderer;
 use Termwind\Repositories\Styles;
 
 use function Termwind\renderUsing;
@@ -13,16 +12,6 @@ uses()->beforeEach(fn () => renderUsing($this->output = new BufferedOutput))
         Styles::flush();
     })->in(__DIR__);
 
-/**
- * Parses the given html to string.
- */
-function parse(string $html): string
-{
-    $html = (new HtmlRenderer)->parse($html);
-
-    return $html->toString();
-}
-
 /**
  * Gets a input stream resource from a string.
  *
